@@ -9,11 +9,12 @@
  * Copyright (c) 1987-1993 The Regents of the University of California.
  * Copyright (c) 1993-1997 Lucent Technologies.
  * Copyright (c) 1994-1997 Sun Microsystems, Inc.
+ * Copyright (c) 1998 by Scriptics Corporation.
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tclCmdIL.c 1.6 98/08/07 11:41:56
+ * RCS: @(#) $Id: tclCmdIL.c,v 1.10 1998/10/13 20:30:22 rjohnson Exp $
  */
 
 #include "tclInt.h"
@@ -126,9 +127,6 @@ static int		InfoPatchLevelCmd _ANSI_ARGS_((ClientData dummy,
 static int		InfoProcsCmd _ANSI_ARGS_((ClientData dummy,
 			    Tcl_Interp *interp, int objc,
 			    Tcl_Obj *CONST objv[]));
-static int		InfoResourceCmd _ANSI_ARGS_((ClientData dummy,
-			    Tcl_Interp *interp, int objc,
-			    Tcl_Obj *CONST objv[]));
 static int		InfoScriptCmd _ANSI_ARGS_((ClientData dummy,
 			    Tcl_Interp *interp, int objc,
 			    Tcl_Obj *CONST objv[]));
@@ -349,14 +347,14 @@ Tcl_InfoObjCmd(clientData, interp, objc, objv)
 	     "complete", "default", "exists", "globals",
 	     "hostname", "level", "library", "loaded",
 	     "locals", "nameofexecutable", "patchlevel", "procs",
-	     "resource", "script", "sharedlibextension", "tclversion", "vars",
+	     "script", "sharedlibextension", "tclversion", "vars",
 	     (char *) NULL};
     enum ISubCmdIdx {
 	    IArgsIdx, IBodyIdx, ICmdCountIdx, ICommandsIdx,
 	    ICompleteIdx, IDefaultIdx, IExistsIdx, IGlobalsIdx,
 	    IHostnameIdx, ILevelIdx, ILibraryIdx, ILoadedIdx,
 	    ILocalsIdx, INameOfExecutableIdx, IPatchLevelIdx, IProcsIdx,
-	    IResourceIdx, IScriptIdx, ISharedLibExtensionIdx, ITclVersionIdx, IVarsIdx
+	    IScriptIdx, ISharedLibExtensionIdx, ITclVersionIdx, IVarsIdx
     } index;
     int result;
 
@@ -420,9 +418,6 @@ Tcl_InfoObjCmd(clientData, interp, objc, objv)
         case IProcsIdx:
 	    result = InfoProcsCmd(clientData, interp, objc, objv);
 	    break;
-        case IResourceIdx:
-	    result = InfoResourceCmd(clientData, interp, objc, objv);
-	    break;
         case IScriptIdx:
 	    result = InfoScriptCmd(clientData, interp, objc, objv);
 	    break;
@@ -768,19 +763,17 @@ InfoCompleteCmd(dummy, interp, objc, objv)
     int objc;			/* Number of arguments. */
     Tcl_Obj *CONST objv[];	/* Argument objects. */
 {
-    char *command;
-
     if (objc != 3) {
         Tcl_WrongNumArgs(interp, 2, objv, "command");
         return TCL_ERROR;
     }
 
-    command = Tcl_GetStringFromObj(objv[2], (int *) NULL);
-    if (Tcl_CommandComplete(command)) {
+    if (TclObjCommandComplete(objv[2])) {
 	Tcl_SetIntObj(Tcl_GetObjResult(interp), 1);
     } else {
 	Tcl_SetIntObj(Tcl_GetObjResult(interp), 0);
     }
+
     return TCL_OK;
 }
 
@@ -1472,59 +1465,6 @@ InfoProcsCmd(dummy, interp, objc, objv)
     return TCL_OK;
 }
 
-/*
- *----------------------------------------------------------------------
- *
- * InfoResourceCmd --
- *
- *      Called to implement the "info resource" command that returns the
- *      content of the names resource. Handles the
- *      following syntax:
- *
- *          info resource resourceName
- *
- * Results:
- *      Returns TCL_OK is successful and TCL_ERROR is there is an error.
- *
- * Side effects:
- *      Returns a result in the interpreter's result object. If there is
- *	an error, the result is an error message.
- *
- *----------------------------------------------------------------------
- */
-
-static int
-InfoResourceCmd(dummy, interp, objc, objv)
-    ClientData dummy;		/* Not used. */
-    Tcl_Interp *interp;		/* Current interpreter. */
-    int objc;			/* Number of arguments. */
-    Tcl_Obj *CONST objv[];	/* Argument objects. */
-{
-    char *resourceName;
-    char **value;
-
-    if (objc != 3) {
-        Tcl_WrongNumArgs(interp, 1, objv, "resource resourceName");
-        return TCL_ERROR;
-    }
-
-    resourceName = Tcl_GetStringFromObj(objv[2], (int *) NULL);
-    value = Tcl_GetStaticFile(resourceName);
-    if (value != (char **) NULL) {
-	char **p = value;
-	while (*p) {
-	    Tcl_AppendToObj(Tcl_GetObjResult(interp), *p, strlen(*p));
-	    Tcl_AppendToObj(Tcl_GetObjResult(interp), "\n", 1);
-	    p++;
-	}
-	return TCL_OK;
-    }
-    Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
-	    "no entry \"", resourceName, "\" in resource",
-	    (char *) NULL);
-    return TCL_ERROR;
-}
-
 /*
  *----------------------------------------------------------------------
  *
@@ -2922,11 +2862,11 @@ DictionaryCompare(left, right)
 	     */
 
 	    zeros = 0;
-	    while ((*right == '0') && (*(right + 1) != '\0')) {
+	    while ((*right == '0') && (isdigit(UCHAR(right[1])))) {
 		right++;
 		zeros--;
 	    }
-	    while ((*left == '0') && (*(left + 1) != '\0')) {
+	    while ((*left == '0') && (isdigit(UCHAR(left[1])))) {
 		left++;
 		zeros++;
 	    }
