@@ -11,36 +11,11 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tclTestObj.c 1.27 97/05/19 17:37:31
+ * RCS: @(#) $Id: tclTestObj.c,v 1.2 1998/09/14 18:40:02 stanton Exp $
  */
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-/*
- * Allow this file to be compiled as loadable library (dll) separate
- * from the Tcl shared library (or dll). We don't want all
- * dll symbols to be exported, only the Objtest_Init() function.
- */
-#undef BUILD_tcl
-
 #include "tclInt.h"
 
-/*
- * TCL_STORAGE_CLASS is set unconditionally to DLLEXPORT because the
- * Objtest_Init declaration is in the source file itself, which is only
- * accessed when we are building a library.
- */
-
-#undef TCL_STORAGE_CLASS
-#define TCL_STORAGE_CLASS DLLEXPORT
-
-#ifdef __cplusplus
-}
-#define dummy /* */
-#endif
-
 /*
  * An array of Tcl_Obj pointers used in the commands that operate on or get
  * the values of Tcl object-valued variables. varPtr[i] is the i-th
@@ -54,8 +29,6 @@ static Tcl_Obj *varPtr[NUMBER_OF_OBJECT_VARS];
  * Forward declarations for procedures defined later in this file:
  */
 
-EXTERN Objtest_Init _ANSI_ARGS_((Tcl_Interp *interp));
-
 static int		CheckIfVarUnset _ANSI_ARGS_((Tcl_Interp *interp,
 			    int varIndex));
 static int		GetVariableIndex _ANSI_ARGS_((Tcl_Interp *interp,
@@ -88,7 +61,7 @@ static int		TeststringobjCmd _ANSI_ARGS_((ClientData dummy,
 /*
  *----------------------------------------------------------------------
  *
- * Tclobjtest_Init --
+ * TclObjTest_Init --
  *
  *	This procedure creates additional commands that are used to test the
  *	Tcl object support.
@@ -104,18 +77,11 @@ static int		TeststringobjCmd _ANSI_ARGS_((ClientData dummy,
  */
 
 int
-#ifdef _USING_PROTOTYPES_
-Objtest_Init (Tcl_Interp *interp)	/* Interpreter for application. */
-#else
-Objtest_Init(interp)
+TclObjTest_Init(interp)
     Tcl_Interp *interp;
-#endif
 {
     register int i;
     
-    if (Tcl_PkgRequire(interp, "Tcl", TCL_VERSION, 1) == NULL) {
-	return TCL_ERROR;
-    }
     for (i = 0;  i < NUMBER_OF_OBJECT_VARS;  i++) {
         varPtr[i] = NULL;
     }
@@ -134,39 +100,8 @@ Objtest_Init(interp)
 	    (ClientData) 0, (Tcl_CmdDeleteProc *) NULL);
     Tcl_CreateObjCommand(interp, "teststringobj", TeststringobjCmd,
 	    (ClientData) 0, (Tcl_CmdDeleteProc *) NULL);
-    return Tcl_PkgProvide(interp, "Objtest", TCL_VERSION);
+    return TCL_OK;
 }
-
-
-/*
- *----------------------------------------------------------------------
- *
- * TclObjTest_Init --
- *
- *	This procedure creates additional commands that are used to test the
- *	Tcl object support. The same as Tclobjtest_Init().
- *
- * Results:
- *	Returns a standard Tcl completion code, and leaves an error
- *	message in interp->result if an error occurs.
- *
- * Side effects:
- *	Creates and registers several new testing commands.
- *
- *----------------------------------------------------------------------
- */
-
-int
-#ifdef _USING_PROTOTYPES_
-TclObjTest_Init (Tcl_Interp *interp)	/* Interpreter for application. */
-#else
-TclObjTest_Init(interp)
-    Tcl_Interp *interp;
-#endif
-{
-    return Objtest_Init(interp);
-}
-
 
 /*
  *----------------------------------------------------------------------
@@ -187,19 +122,11 @@ TclObjTest_Init(interp)
  */
 
 static int
-#ifdef _USING_PROTOTYPES_
-TestbooleanobjCmd (
-    ClientData dummy,		/* Not used. */
-    Tcl_Interp *interp,		/* Current interpreter. */
-    int objc,			/* Number of arguments. */
-    Tcl_Obj *CONST objv[])	/* Argument objects. */
-#else
-TestbooleanobjCmd(dummy, interp, objc, objv)
-    ClientData dummy;		/* Not used. */
+TestbooleanobjCmd(clientData, interp, objc, objv)
+    ClientData clientData;	/* Not used. */
     Tcl_Interp *interp;		/* Current interpreter. */
     int objc;			/* Number of arguments. */
     Tcl_Obj *CONST objv[];	/* Argument objects. */
-#endif
 {
     int varIndex, boolValue, length;
     char *index, *subCmd;
@@ -294,19 +221,11 @@ TestbooleanobjCmd(dummy, interp, objc, objv)
  */
 
 static int
-#ifdef _USING_PROTOTYPES_
-TestconvertobjCmd (
-    ClientData dummy,		/* Not used. */
-    Tcl_Interp *interp,		/* Current interpreter. */
-    int objc,			/* Number of arguments. */
-    Tcl_Obj *CONST objv[])	/* Argument objects. */
-#else
-TestconvertobjCmd(dummy, interp, objc, objv)
-    ClientData dummy;		/* Not used. */
+TestconvertobjCmd(clientData, interp, objc, objv)
+    ClientData clientData;	/* Not used. */
     Tcl_Interp *interp;		/* Current interpreter. */
     int objc;			/* Number of arguments. */
     Tcl_Obj *CONST objv[];	/* Argument objects. */
-#endif
 {
     int length;
     char *subCmd;
@@ -363,19 +282,11 @@ TestconvertobjCmd(dummy, interp, objc, objv)
  */
 
 static int
-#ifdef _USING_PROTOTYPES_
-TestdoubleobjCmd (
-    ClientData dummy,		/* Not used. */
-    Tcl_Interp *interp,		/* Current interpreter. */
-    int objc,			/* Number of arguments. */
-    Tcl_Obj *CONST objv[])	/* Argument objects. */
-#else
-TestdoubleobjCmd(dummy, interp, objc, objv)
-    ClientData dummy;		/* Not used. */
+TestdoubleobjCmd(clientData, interp, objc, objv)
+    ClientData clientData;	/* Not used. */
     Tcl_Interp *interp;		/* Current interpreter. */
     int objc;			/* Number of arguments. */
     Tcl_Obj *CONST objv[];	/* Argument objects. */
-#endif
 {
     int varIndex, length;
     double doubleValue;
@@ -490,25 +401,17 @@ TestdoubleobjCmd(dummy, interp, objc, objv)
  */
 
 static int
-#ifdef _USING_PROTOTYPES_
-TestindexobjCmd (
-    ClientData dummy,		/* Not used. */
-    Tcl_Interp *interp,		/* Current interpreter. */
-    int objc,			/* Number of arguments. */
-    Tcl_Obj *CONST objv[])	/* Argument objects. */
-#else
-TestindexobjCmd(dummy, interp, objc, objv)
-    ClientData dummy;		/* Not used. */
+TestindexobjCmd(clientData, interp, objc, objv)
+    ClientData clientData;	/* Not used. */
     Tcl_Interp *interp;		/* Current interpreter. */
     int objc;			/* Number of arguments. */
     Tcl_Obj *CONST objv[];	/* Argument objects. */
-#endif
 {
-    int allowAbbrev, index, index2, setError, i, length, result;
+    int allowAbbrev, index, index2, setError, i, dummy, result;
     char **argv;
     static char *tablePtr[] = {"a", "b", "check", (char *) NULL};
 
-    if ((objc == 3) && (strcmp(Tcl_GetStringFromObj(objv[1], &length),
+    if ((objc == 3) && (strcmp(Tcl_GetStringFromObj(objv[1], &dummy),
 	    "check") == 0)) {
 	/*
 	 * This code checks to be sure that the results of
@@ -543,7 +446,7 @@ TestindexobjCmd(dummy, interp, objc, objv)
     }
     argv = (char **) ckalloc((unsigned) ((objc-3) * sizeof(char *)));
     for (i = 4; i < objc; i++) {
-	argv[i-4] = Tcl_GetStringFromObj(objv[i], &length);
+	argv[i-4] = Tcl_GetStringFromObj(objv[i], &dummy);
     }
     argv[objc-4] = NULL;
     result = Tcl_GetIndexFromObj(setError ? interp : NULL, objv[3],
@@ -574,19 +477,11 @@ TestindexobjCmd(dummy, interp, objc, objv)
  */
 
 static int
-#ifdef _USING_PROTOTYPES_
-TestintobjCmd (
-    ClientData dummy,		/* Not used. */
-    Tcl_Interp *interp,		/* Current interpreter. */
-    int objc,			/* Number of arguments. */
-    Tcl_Obj *CONST objv[])	/* Argument objects. */
-#else
-TestintobjCmd(dummy, interp, objc, objv)
-    ClientData dummy;		/* Not used. */
+TestintobjCmd(clientData, interp, objc, objv)
+    ClientData clientData;	/* Not used. */
     Tcl_Interp *interp;		/* Current interpreter. */
     int objc;			/* Number of arguments. */
     Tcl_Obj *CONST objv[];	/* Argument objects. */
-#endif
 {
     int intValue, varIndex, length, i;
     long longValue;
@@ -780,19 +675,11 @@ TestintobjCmd(dummy, interp, objc, objv)
  */
 
 static int
-#ifdef _USING_PROTOTYPES_
-TestobjCmd (
-    ClientData dummy,		/* Not used. */
-    Tcl_Interp *interp,		/* Current interpreter. */
-    int objc,			/* Number of arguments. */
-    Tcl_Obj *CONST objv[])	/* Argument objects. */
-#else
-TestobjCmd(dummy, interp, objc, objv)
-    ClientData dummy;		/* Not used. */
+TestobjCmd(clientData, interp, objc, objv)
+    ClientData clientData;	/* Not used. */
     Tcl_Interp *interp;		/* Current interpreter. */
     int objc;			/* Number of arguments. */
     Tcl_Obj *CONST objv[];	/* Argument objects. */
-#endif
 {
     int varIndex, destIndex, i;
     char *index, *subCmd, *string;
@@ -956,19 +843,11 @@ TestobjCmd(dummy, interp, objc, objv)
  */
 
 static int
-#ifdef _USING_PROTOTYPES_
-TeststringobjCmd (
-    ClientData dummy,		/* Not used. */
-    Tcl_Interp *interp,		/* Current interpreter. */
-    int objc,			/* Number of arguments. */
-    Tcl_Obj *CONST objv[])	/* Argument objects. */
-#else
-TeststringobjCmd(dummy, interp, objc, objv)
-    ClientData dummy;		/* Not used. */
+TeststringobjCmd(clientData, interp, objc, objv)
+    ClientData clientData;	/* Not used. */
     Tcl_Interp *interp;		/* Current interpreter. */
     int objc;			/* Number of arguments. */
     Tcl_Obj *CONST objv[];	/* Argument objects. */
-#endif
 {
     int varIndex, option, i, length;
 #define MAX_STRINGS 10
@@ -1131,15 +1010,9 @@ TeststringobjCmd(dummy, interp, objc, objv)
  */
 
 static void
-#ifdef _USING_PROTOTYPES_
-SetVarToObj (
-    int varIndex,		/* Designates the assignment variable. */
-    Tcl_Obj *objPtr)		/* Points to object to assign to var. */
-#else
 SetVarToObj(varIndex, objPtr)
     int varIndex;		/* Designates the assignment variable. */
     Tcl_Obj *objPtr;		/* Points to object to assign to var. */
-#endif
 {
     if (varPtr[varIndex] != NULL) {
 	Tcl_DecrRefCount(varPtr[varIndex]);
@@ -1167,21 +1040,12 @@ SetVarToObj(varIndex, objPtr)
  */
 
 static int
-#ifdef _USING_PROTOTYPES_
-GetVariableIndex (
-    Tcl_Interp *interp,         /* Interpreter for error reporting. */
-    char *string,               /* String containing a variable index
-				 * specified as a nonnegative number less
-				 * than NUMBER_OF_OBJECT_VARS. */
-    int *indexPtr)              /* Place to store converted result. */
-#else
 GetVariableIndex(interp, string, indexPtr)
     Tcl_Interp *interp;         /* Interpreter for error reporting. */
     char *string;               /* String containing a variable index
 				 * specified as a nonnegative number less
 				 * than NUMBER_OF_OBJECT_VARS. */
     int *indexPtr;              /* Place to store converted result. */
-#endif
 {
     int index;
     
@@ -1217,15 +1081,9 @@ GetVariableIndex(interp, string, indexPtr)
  */
 
 static int
-#ifdef _USING_PROTOTYPES_
-CheckIfVarUnset (
-    Tcl_Interp *interp,		/* Interpreter for error reporting. */
-    int varIndex)		/* Index of the test variable to check. */
-#else
 CheckIfVarUnset(interp, varIndex)
     Tcl_Interp *interp;		/* Interpreter for error reporting. */
     int varIndex;		/* Index of the test variable to check. */
-#endif
 {
     if (varPtr[varIndex] == NULL) {
 	char buf[100];
