@@ -9,7 +9,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tclWinChan.c 1.75 97/09/26 16:17:46
+ * RCS: @(#) $Id: tclWinChan.c,v 1.3 1998/09/14 18:40:19 stanton Exp $
  */
 
 #include "tclWinInt.h"
@@ -28,13 +28,6 @@ static char channelName[CHANNEL_NAME_SIZE+1];
 
 static int initialized = 0;
 
-/*
- * The following define declares a new user message for use on the
- * pipe window.
- */
-
-#define FILE_MESSAGE	WM_USER+20
-
 /*
  * State flags used in the info structures below.
  */
@@ -57,9 +50,6 @@ typedef struct FileInfo {
 				 * which events should be reported. */
     int flags;			/* State flags, see above for a list. */
     HANDLE handle;		/* Input/output file. */
-    OVERLAPPED wOverResult;	/* Overlapped write result */
-    TclWinReaderInfo *readerInfo; /* File reader data */
-    struct FileInfo *nextLPtr;	/* Pointer to next created file */ 
     struct FileInfo *nextPtr;	/* Pointer to next registered file. */
 } FileInfo;
 
@@ -83,19 +73,6 @@ typedef struct FileEvent {
 				 * pointer. */
 } FileEvent;
 
-/*
- * File notification window.  This window is used to receive file
- * notification events.
- */
-
-static HWND fileWindow = NULL;
-
-/*
- * Window class for creating the file notification window.
- */
-
-static ATOM fileClass;
-
 /*
  * Static routines for this file:
  */
@@ -105,9 +82,6 @@ static int		ComGetOptionProc _ANSI_ARGS_((ClientData instanceData,
 			    Tcl_DString *dsPtr));
 static int		ComInputProc _ANSI_ARGS_((ClientData instanceData,
 	            	    char *buf, int toRead, int *errorCode));
-static int		ComOutputProc _ANSI_ARGS_((ClientData instanceData,
-			    char *buf, int toWrite, int *errorCode));
-static DWORD WINAPI	ComWatchThread (LPVOID *arg);
 static int		ComSetOptionProc _ANSI_ARGS_((ClientData instanceData,
 			    Tcl_Interp *interp, char *optionName, 
 			    char *value));
@@ -128,8 +102,6 @@ static int		FileInputProc _ANSI_ARGS_((ClientData instanceData,
 	            	    char *buf, int toRead, int *errorCode));
 static int		FileOutputProc _ANSI_ARGS_((ClientData instanceData,
 			    char *buf, int toWrite, int *errorCode));
-static LRESULT CALLBACK FileProc (HWND hwnd, UINT message, WPARAM wParam,
-			    LPARAM lParam);
 static int		FileSeekProc _ANSI_ARGS_((ClientData instanceData,
 			    long offset, int mode, int *errorCode));
 static void		FileSetupProc _ANSI_ARGS_((ClientData clientData,
@@ -160,7 +132,7 @@ static Tcl_ChannelType comChannelType = {
     FileBlockProc,		/* Set blocking or non-blocking mode.*/
     FileCloseProc,		/* Close proc. */
     ComInputProc,		/* Input proc. */
-    ComOutputProc,		/* Output proc. */
+    FileOutputProc,		/* Output proc. */
     NULL,			/* Seek proc. */
     ComSetOptionProc,		/* Set option proc. */
     ComGetOptionProc,		/* Get option proc. */
@@ -187,98 +159,12 @@ static Tcl_ChannelType comChannelType = {
 static void
 FileInit()
 {
-    WNDCLASS class;
-
-    if (initialized) {
-	return;
-    }
-
     initialized = 1;
     firstFilePtr = NULL;
-
-    /*
-     * Register the async notification window class and window.
-     */
-
-    class.style = 0;
-    class.cbClsExtra = 0;
-    class.cbWndExtra = 0;
-    class.hInstance = TclWinGetTclInstance();
-    class.hbrBackground = NULL;
-    class.lpszMenuName = NULL;
-    class.lpszClassName = "TclFile";
-    class.lpfnWndProc = FileProc;
-    class.hIcon = NULL;
-    class.hCursor = NULL;
-
-    fileClass = RegisterClass(&class);
-    if (!fileClass) {
-	return;
-    }
-    fileWindow = CreateWindowEx(0, (LPCTSTR)fileClass, "TclFile",
-	    WS_OVERLAPPED, 0, 0, 0, 0, NULL, NULL,
-	    TclWinGetTclInstance(), NULL);
-    if (fileWindow == NULL) {
-	TclWinConvertError(GetLastError());
-	UnregisterClass((LPCTSTR)fileClass, TclWinGetTclInstance());
-	return;
-    }
-
     Tcl_CreateEventSource(FileSetupProc, FileCheckProc, NULL);
     Tcl_CreateExitHandler(FileChannelExitHandler, NULL);
 }
 
-/*
- *----------------------------------------------------------------------
- *
- * FileProc --
- *
- *	This function is called when WSAAsyncSelect has been used
- *	to register interest in a file event, and the event has
- *	occurred.
- *
- * Results:
- *	0 on success.
- *
- * Side effects:
- *	The flags for the given file are updated to reflect the
- *	event that occured.
- *
- *----------------------------------------------------------------------
- */
-
-static LRESULT CALLBACK
-FileProc(hwnd, message, wParam, lParam)
-    HWND hwnd;
-    UINT message;
-    WPARAM wParam;
-    LPARAM lParam;
-{
-    int event;
-    HANDLE file;
-    FileInfo *filePtr;
-
-    if ((hwnd != fileWindow) || (message != FILE_MESSAGE)) {
-	return DefWindowProc(hwnd, message, wParam, lParam);
-    }
-    
-    file = (HANDLE) wParam;
-    event = lParam;
-
-    /*
-     * Find the specified file on the file list and update its
-     * check flags.
-     */
-
-    for (filePtr = firstFilePtr; filePtr != NULL; filePtr = filePtr->nextPtr) {
-	if (filePtr->readerInfo->rHandle == file) {
-	    filePtr->readerInfo->readyMask |= event;
-	    break;
-	}
-    }
-    return 0;
-}
-
 /*
  *----------------------------------------------------------------------
  *
@@ -300,8 +186,6 @@ static void
 FileChannelExitHandler(clientData)
     ClientData clientData;	/* Old window proc */
 {
-    DestroyWindow(fileWindow);
-    UnregisterClass((LPCTSTR)fileClass, TclWinGetTclInstance());
     Tcl_DeleteEventSource(FileSetupProc, FileCheckProc, NULL);
     initialized = 0;
 }
@@ -340,21 +224,7 @@ FileSetupProc(data, flags)
      */
 
     for (infoPtr = firstFilePtr; infoPtr != NULL; infoPtr = infoPtr->nextPtr) {
-	if (infoPtr->watchMask & TCL_READABLE) {
-	    if (infoPtr->readerInfo->rType == FILE_TYPE_CONSOLE) {
-		if (infoPtr->readerInfo->rThread == NULL) {
-		    TclWinReaderStart(infoPtr->readerInfo, TclWinReaderThread);
-		}
-		SetEvent(infoPtr->readerInfo->rGoEvent);
-	    } else if (infoPtr->readerInfo->rType == FILE_TYPE_COM) {
-		if (infoPtr->readerInfo->rThread == NULL) {
-		    TclWinReaderStart(infoPtr->readerInfo, ComWatchThread);
-		}
-		SetEvent(infoPtr->readerInfo->rGoEvent);
-	    }
-	}
-
-	if (infoPtr->readerInfo->readyMask & infoPtr->watchMask) {
+	if (infoPtr->watchMask) {
 	    Tcl_SetMaxBlockTime(&blockTime);
 	    break;
 	}
@@ -397,31 +267,7 @@ FileCheckProc(data, flags)
      */
 
     for (infoPtr = firstFilePtr; infoPtr != NULL; infoPtr = infoPtr->nextPtr) {
-	if (infoPtr->watchMask & TCL_READABLE) {
-	    if (infoPtr->readerInfo->rThread == NULL) {
-		if (infoPtr->readerInfo->rType == FILE_TYPE_CONSOLE) {
-		    TclWinReaderStart(infoPtr->readerInfo, TclWinReaderThread);
-		} else if (infoPtr->readerInfo->rType == FILE_TYPE_COM) {
-		    TclWinReaderStart(infoPtr->readerInfo, ComWatchThread);
-		}
-		SetEvent(infoPtr->readerInfo->rGoEvent);
-	    }
-	}
-	if ((infoPtr->readerInfo->readyMask & infoPtr->watchMask)
-	    && !(infoPtr->flags & FILE_PENDING))
-	{
-	    if (infoPtr->readerInfo->rType == FILE_TYPE_COM) {
-		COMSTAT cs;
-		DWORD dw;
-
-		if (ClearCommError(infoPtr->readerInfo->rHandle, &dw, &cs)) {
-		    if (dw != 0 || cs.cbInQue == 0) {
-			infoPtr->readerInfo->readyMask &= ~TCL_READABLE;
-			return;
-		    }
-		}
-
-	    }
+	if (infoPtr->watchMask && !(infoPtr->flags & FILE_PENDING)) {
 	    infoPtr->flags |= FILE_PENDING;
 	    evPtr = (FileEvent *) ckalloc(sizeof(FileEvent));
 	    evPtr->header.proc = FileEventProc;
@@ -514,10 +360,8 @@ FileBlockProc(instanceData, mode)
 
     if (mode == TCL_MODE_NONBLOCKING) {
 	infoPtr->flags |= FILE_ASYNC;
-	infoPtr->readerInfo->async = 1;
     } else {
 	infoPtr->flags &= ~(FILE_ASYNC);
-	infoPtr->readerInfo->async = 0;
     }
     return 0;
 }
@@ -553,6 +397,10 @@ FileCloseProc(instanceData, interp)
 
     FileWatchProc(instanceData, 0);
 
+    if (CloseHandle(fileInfoPtr->handle) == FALSE) {
+	TclWinConvertError(GetLastError());
+	errorCode = errno;
+    }
     for (nextPtrPtr = &firstFilePtr; (*nextPtrPtr) != NULL;
 	 nextPtrPtr = &((*nextPtrPtr)->nextPtr)) {
 	if ((*nextPtrPtr) == fileInfoPtr) {
@@ -560,15 +408,6 @@ FileCloseProc(instanceData, interp)
 	    break;
 	}
     }
-
-    if (CloseHandle(fileInfoPtr->handle) == FALSE) {
-	TclWinConvertError(GetLastError());
-	errorCode = errno;
-    }
-    TclWinReaderFree(fileInfoPtr->readerInfo);
-    if (fileInfoPtr->wOverResult.hEvent) {
-	CloseHandle(fileInfoPtr->wOverResult.hEvent);
-    }
     ckfree((char *)fileInfoPtr);
     return errorCode;
 }
@@ -660,22 +499,17 @@ FileInputProc(instanceData, buf, bufSize, errorCode)
      * problem exists for files being read over the network.
      */
 
-    if (infoPtr->readerInfo->rType != FILE_TYPE_CONSOLE &&
-	infoPtr->readerInfo->rType != FILE_TYPE_COM)
-    {
-	if (ReadFile(infoPtr->handle, (LPVOID) buf, (DWORD) bufSize,
-	    &bytesRead, (LPOVERLAPPED) NULL) != FALSE) {
-	    return bytesRead;
-	}
-    
-	TclWinConvertError(GetLastError());
-	*errorCode = errno;
-	if (errno == EPIPE) {
-	    return 0;
-	}
-	return -1;
+    if (ReadFile(infoPtr->handle, (LPVOID) buf, (DWORD) bufSize, &bytesRead,
+            (LPOVERLAPPED) NULL) != FALSE) {
+	return bytesRead;
     }
-    return TclWinReaderInput(infoPtr->readerInfo, buf, bufSize, errorCode);
+    
+    TclWinConvertError(GetLastError());
+    *errorCode = errno;
+    if (errno == EPIPE) {
+	return 0;
+    }
+    return -1;
 }
 
 /*
@@ -760,7 +594,7 @@ FileWatchProc(instanceData, mask)
      */
 
     infoPtr->watchMask = mask & infoPtr->validMask;
-    if (infoPtr->readerInfo->readyMask & infoPtr->watchMask) {
+    if (infoPtr->watchMask) {
 	Tcl_SetMaxBlockTime(&blockTime);
     }
 }
@@ -799,80 +633,6 @@ FileGetHandleProc(instanceData, direction, handlePtr)
     }
 }
 
-/*
- *----------------------------------------------------------------------
- *
- * ComWatchThread --
- *
- *	This routine just waits on the a COM port for a character to
- *	be placed on the input queue.  At that point, it posts a
- *	message saying that something might want to try and read the
- *	serial port.
- *
- * Results:
- *	This thread exits when the child is done.
- *
- * Side Effects:
- *	This buffer should not be changed until the data has been copied.
- *
- *----------------------------------------------------------------------
- */
-static DWORD WINAPI
-ComWatchThread(arg)
-    LPVOID *arg;
-{
-    TclWinReaderInfo *infoPtr = (TclWinReaderInfo *) arg;
-    HANDLE handle = infoPtr->rHandle;
-    BOOL b;
-    DWORD mask;
-    DWORD err;
-    DWORD bytesWritten;
-    OVERLAPPED overlapped;
-
-    overlapped.hEvent = CreateEvent(NULL, TRUE, FALSE, NULL);
-    SetCommMask(handle, EV_RXCHAR);
-    while (1) {
-	if (infoPtr->rHandleClosed) {
-	    break;
-	}
-
-	/*
-	 * Post a new message whenever we know there is something
-	 * that can be read
-	 */
-
-	WaitForSingleObject(infoPtr->rGoEvent, INFINITE);
-	b = WaitCommEvent(handle, &mask, &overlapped);
-	if (b == FALSE) {
-	    err = GetLastError();
-	    if (err == ERROR_IO_PENDING) {
-		if (GetOverlappedResult(handle, &overlapped,
-		    &bytesWritten, TRUE) == FALSE) {
-		    err = GetLastError();
-		    break;
-		}
-	    } else {
-		break;
-	    }
-	}
-	if (mask & EV_RXCHAR) {
-	    ResetEvent(infoPtr->rGoEvent);
-	    PostMessage(infoPtr->postWin, infoPtr->postMsg,
-		(UINT) handle, TCL_READABLE);
-	}
-    }
-    CloseHandle(overlapped.hEvent);
-
-    infoPtr->eof = 1;
-    PostMessage(infoPtr->postWin, infoPtr->postMsg, (UINT) handle, TCL_READABLE);
-
-    WaitForSingleObject(infoPtr->rSemaphore, INFINITE);
-
-    TclWinReaderFree(infoPtr);
-    ExitThread(0);
-    return 0;
-}
-
 /*
  *----------------------------------------------------------------------
  *
@@ -903,13 +663,10 @@ ComInputProc(instanceData, buf, bufSize, errorCode)
     DWORD bytesRead;
     DWORD dw;
     COMSTAT cs;
-    DWORD err;
 
     *errorCode = 0;
     infoPtr = (FileInfo *) instanceData;
 
-    infoPtr->readerInfo->readyMask &= ~TCL_READABLE;
-
     if (ClearCommError(infoPtr->handle, &dw, &cs)) {
 	if (dw != 0) {
 	    *errorCode = EIO;
@@ -930,73 +687,13 @@ ComInputProc(instanceData, buf, bufSize, errorCode)
     }
     
     if (ReadFile(infoPtr->handle, (LPVOID) buf, (DWORD) bufSize, &bytesRead,
-            &infoPtr->readerInfo->rOverResult) == FALSE) {
-	err = GetLastError();
-	if (err == ERROR_IO_PENDING) {
-	    if (GetOverlappedResult(infoPtr->handle,
-		&infoPtr->readerInfo->rOverResult,
-		&bytesRead, TRUE) == FALSE)
-	    {
-		err = GetLastError();
-	    }
-	}
-	if (err != ERROR_IO_PENDING) {
-	    TclWinConvertError(err);
-	    *errorCode = errno;
-	    return -1;
-	}
+            (LPOVERLAPPED) NULL) == FALSE) {
+	TclWinConvertError(GetLastError());
+	*errorCode = errno;
+	return -1;
     }
-
-    return bytesRead;
-}
-
-/*
- *----------------------------------------------------------------------
- *
- * ComOutputProc --
- *
- *	Writes the given output on the IO channel. Returns count of how
- *	many characters were actually written, and an error indication.
- *
- * Results:
- *	A count of how many characters were written is returned and an
- *	error indication is returned in an output argument.
- *
- * Side effects:
- *	Writes output on the actual channel.
- *
- *----------------------------------------------------------------------
- */
-
-static int
-ComOutputProc(instanceData, buf, toWrite, errorCode)
-    ClientData instanceData;		/* File state. */
-    char *buf;				/* The data buffer. */
-    int toWrite;			/* How many bytes to write? */
-    int *errorCode;			/* Where to store error code. */
-{
-    FileInfo *infoPtr = (FileInfo *) instanceData;
-    DWORD bytesWritten;
-    DWORD err;
     
-    *errorCode = 0;
-
-    if (WriteFile(infoPtr->handle, (LPVOID) buf, (DWORD) toWrite,
-	    &bytesWritten, &infoPtr->wOverResult) == FALSE) {
-	err = GetLastError();
-	if (err == ERROR_IO_PENDING) {
-	    if (GetOverlappedResult(infoPtr->handle, &infoPtr->wOverResult,
-		    &bytesWritten, TRUE) == FALSE) {
-		err = GetLastError();
-	    }
-	}
-	if (err != ERROR_IO_PENDING) {
-	    TclWinConvertError(GetLastError());
-	    *errorCode = errno;
-	    return -1;
-	}
-    }
-    return bytesWritten;
+    return bytesRead;
 }
 
 /*
@@ -1268,8 +965,8 @@ TclpOpenFileChannel(interp, fileName, modeString, permissions)
         return NULL;
     }
 
-    dcb.DCBlength = sizeof( DCB ) ;
     if (GetFileType(handle) == FILE_TYPE_CHAR) {
+	dcb.DCBlength = sizeof( DCB ) ;
 	if (GetCommState(handle, &dcb)) {
 	    /*
 	     * This is a com port.  Reopen it with the correct modes. 
@@ -1279,7 +976,7 @@ TclpOpenFileChannel(interp, fileName, modeString, permissions)
 
 	    CloseHandle(handle);
 	    handle = CreateFile(nativeName, accessMode, 0, NULL, OPEN_EXISTING,
-		    flags | FILE_FLAG_OVERLAPPED, NULL);
+		    flags, NULL);
 	    if (handle == INVALID_HANDLE_VALUE) {
 		goto openerr;
 	    }
@@ -1317,13 +1014,6 @@ TclpOpenFileChannel(interp, fileName, modeString, permissions)
     infoPtr->watchMask = 0;
     infoPtr->flags = (mode & O_APPEND) ? FILE_APPEND : 0;
     infoPtr->handle = handle;
-    infoPtr->readerInfo = TclWinReaderNew(fileWindow, FILE_MESSAGE, handle);
-    memset(&infoPtr->wOverResult, 0, sizeof(infoPtr->wOverResult));
-    if (channelTypePtr == &comChannelType) {
-	infoPtr->wOverResult.hEvent = CreateEvent(NULL, TRUE, FALSE, NULL);
-    } else {
-	infoPtr->wOverResult.hEvent = NULL;
-    }
    
     sprintf(channelName, "file%d", (int) handle);
 
@@ -1377,8 +1067,6 @@ Tcl_MakeFileChannel(handle, mode)
 {
     char channelName[20];
     FileInfo *infoPtr;
-    DCB dcb;
-    Tcl_ChannelType *channelTypePtr;
 
     if (!initialized) {
 	FileInit();
@@ -1400,18 +1088,6 @@ Tcl_MakeFileChannel(handle, mode)
 	}
     }
 
-    /*
-     * See if the handle is a serial device handle as those need to be
-     * handled differently.
-     */
-
-    dcb.DCBlength = sizeof( DCB ) ;
-    if (GetCommState(handle, &dcb)) {
-	channelTypePtr = &comChannelType;
-    } else {
-	channelTypePtr = &fileChannelType;
-    }
-
     infoPtr = (FileInfo *) ckalloc((unsigned) sizeof(FileInfo));
     infoPtr->nextPtr = firstFilePtr;
     firstFilePtr = infoPtr;
@@ -1419,10 +1095,8 @@ Tcl_MakeFileChannel(handle, mode)
     infoPtr->watchMask = 0;
     infoPtr->flags = 0;
     infoPtr->handle = (HANDLE) handle;
-    infoPtr->channel = Tcl_CreateChannel(channelTypePtr, channelName,
+    infoPtr->channel = Tcl_CreateChannel(&fileChannelType, channelName,
             (ClientData) infoPtr, mode);
-    infoPtr->readerInfo = TclWinReaderNew(fileWindow, FILE_MESSAGE, handle);
-    memset(&infoPtr->wOverResult, 0, sizeof(infoPtr->wOverResult));
 
     /*
      * Windows files have AUTO translation mode and ^Z eof char on input.
@@ -1457,52 +1131,30 @@ TclGetDefaultStdChannel(type)
     Tcl_Channel channel;
     HANDLE handle;
     int mode;
-    int modeEquiv;
     char *bufMode;
     DWORD handleId;		/* Standard handle to retrieve. */
-    DWORD handleIdEquiv;	/* Check if this handle is equivalent */
 
-    handleIdEquiv = 0xFFFFFFFF;
     switch (type) {
 	case TCL_STDIN:
 	    handleId = STD_INPUT_HANDLE;
 	    mode = TCL_READABLE;
-	    handleIdEquiv = STD_OUTPUT_HANDLE;
-	    modeEquiv = TCL_WRITABLE;
 	    bufMode = "line";
 	    break;
 	case TCL_STDOUT:
 	    handleId = STD_OUTPUT_HANDLE;
 	    mode = TCL_WRITABLE;
-	    handleIdEquiv = STD_INPUT_HANDLE;
-	    modeEquiv = TCL_READABLE;
 	    bufMode = "line";
 	    break;
 	case TCL_STDERR:
 	    handleId = STD_ERROR_HANDLE;
 	    mode = TCL_WRITABLE;
-	    handleIdEquiv = STD_INPUT_HANDLE;
-	    modeEquiv = TCL_READABLE;
 	    bufMode = "none";
 	    break;
 	default:
 	    panic("TclGetDefaultStdChannel: Unexpected channel type");
 	    break;
     }
-
-    /*
-     * If two or three of the standard handles are same, but sure to
-     * open the handle with all necessary permissions so it won't crash
-     * later.  This happens when stdin and stdout have been redirected
-     * to the same handle.
-     */
-
     handle = GetStdHandle(handleId);
-    if (handleIdEquiv != 0xFFFFFFFF) {
-	if (GetStdHandle(handleIdEquiv) == handle) {
-	    mode |= modeEquiv;
-	}
-    }
 
     /*
      * Note that we need to check for 0 because Windows will return 0 if this
