@@ -8,7 +8,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tclWinSock.c 1.80 97/10/09 18:24:59
+ * RCS: @(#) $Id: tclWinSock.c,v 1.3 1998/09/14 18:40:20 stanton Exp $
  */
 
 #include "tclInt.h"
@@ -272,79 +272,71 @@ InitSockets()
 	return;
     }
 
-/* CYGNUS LOCAL */
-#ifdef __GNUC__
-/* gcc can't handle `PASCAL FAR' in a cast.  */
-#define PASCAL_FAR
-#else
-#define PASCAL_FAR PASCAL FAR
-#endif
-
-    winSock.accept = (SOCKET (PASCAL_FAR *)(SOCKET s,
+    winSock.accept = (SOCKET (PASCAL FAR *)(SOCKET s,
             struct sockaddr FAR *addr, int FAR *addrlen))
         GetProcAddress(winSock.hInstance, "accept");
-    winSock.bind = (int (PASCAL_FAR *)(SOCKET s,
+    winSock.bind = (int (PASCAL FAR *)(SOCKET s,
             const struct sockaddr FAR *addr, int namelen))
         GetProcAddress(winSock.hInstance, "bind");
-    winSock.closesocket = (int (PASCAL_FAR *)(SOCKET s))
+    winSock.closesocket = (int (PASCAL FAR *)(SOCKET s))
         GetProcAddress(winSock.hInstance, "closesocket");
-    winSock.connect = (int (PASCAL_FAR *)(SOCKET s,
+    winSock.connect = (int (PASCAL FAR *)(SOCKET s,
             const struct sockaddr FAR *name, int namelen))
         GetProcAddress(winSock.hInstance, "connect");
-    winSock.ioctlsocket = (int (PASCAL_FAR *)(SOCKET s, long cmd,
+    winSock.ioctlsocket = (int (PASCAL FAR *)(SOCKET s, long cmd,
             u_long FAR *argp)) GetProcAddress(winSock.hInstance, "ioctlsocket");
-    winSock.getsockopt = (int (PASCAL_FAR *)(SOCKET s,
+    winSock.getsockopt = (int (PASCAL FAR *)(SOCKET s,
             int level, int optname, char FAR * optval, int FAR *optlen))
         GetProcAddress(winSock.hInstance, "getsockopt");
-    winSock.htons = (u_short (PASCAL_FAR *)(u_short hostshort))
+    winSock.htons = (u_short (PASCAL FAR *)(u_short hostshort))
         GetProcAddress(winSock.hInstance, "htons");
-    winSock.inet_addr = (unsigned long (PASCAL_FAR *)(const char FAR *cp))
+    winSock.inet_addr = (unsigned long (PASCAL FAR *)(const char FAR *cp))
         GetProcAddress(winSock.hInstance, "inet_addr");
-    winSock.inet_ntoa = (char FAR * (PASCAL_FAR *)(struct in_addr in))
+    winSock.inet_ntoa = (char FAR * (PASCAL FAR *)(struct in_addr in))
         GetProcAddress(winSock.hInstance, "inet_ntoa");
-    winSock.listen = (int (PASCAL_FAR *)(SOCKET s, int backlog))
+    winSock.listen = (int (PASCAL FAR *)(SOCKET s, int backlog))
         GetProcAddress(winSock.hInstance, "listen");
-    winSock.ntohs = (u_short (PASCAL_FAR *)(u_short netshort))
+    winSock.ntohs = (u_short (PASCAL FAR *)(u_short netshort))
         GetProcAddress(winSock.hInstance, "ntohs");
-    winSock.recv = (int (PASCAL_FAR *)(SOCKET s, char FAR * buf,
+    winSock.recv = (int (PASCAL FAR *)(SOCKET s, char FAR * buf,
             int len, int flags)) GetProcAddress(winSock.hInstance, "recv");
-    winSock.select = (int (PASCAL_FAR *)(int nfds, fd_set FAR * readfds,
+    winSock.select = (int (PASCAL FAR *)(int nfds, fd_set FAR * readfds,
 	    fd_set FAR * writefds, fd_set FAR * exceptfds,
 	    const struct timeval FAR * tiemout))
 	GetProcAddress(winSock.hInstance, "select");
-    winSock.send = (int (PASCAL_FAR *)(SOCKET s, const char FAR * buf,
+    winSock.send = (int (PASCAL FAR *)(SOCKET s, const char FAR * buf,
             int len, int flags)) GetProcAddress(winSock.hInstance, "send");
-    winSock.setsockopt = (int (PASCAL_FAR *)(SOCKET s, int level,
+    winSock.setsockopt = (int (PASCAL FAR *)(SOCKET s, int level,
             int optname, const char FAR * optval, int optlen))
         GetProcAddress(winSock.hInstance, "setsockopt");
-    winSock.shutdown = (int (PASCAL_FAR *)(SOCKET s, int how))
+    winSock.shutdown = (int (PASCAL FAR *)(SOCKET s, int how))
         GetProcAddress(winSock.hInstance, "shutdown");
-    winSock.socket = (SOCKET (PASCAL_FAR *)(int af, int type,
+    winSock.socket = (SOCKET (PASCAL FAR *)(int af, int type,
             int protocol)) GetProcAddress(winSock.hInstance, "socket");
-    winSock.gethostbyaddr = (struct hostent FAR * (PASCAL_FAR *)
+    winSock.gethostbyaddr = (struct hostent FAR * (PASCAL FAR *)
             (const char FAR *addr, int addrlen, int addrtype))
         GetProcAddress(winSock.hInstance, "gethostbyaddr");
-    winSock.gethostbyname = (struct hostent FAR * (PASCAL_FAR *)
+    winSock.gethostbyname = (struct hostent FAR * (PASCAL FAR *)
             (const char FAR *name))
         GetProcAddress(winSock.hInstance, "gethostbyname");
-    winSock.gethostname = (int (PASCAL_FAR *)(char FAR * name,
+    winSock.gethostname = (int (PASCAL FAR *)(char FAR * name,
             int namelen)) GetProcAddress(winSock.hInstance, "gethostname");
-    winSock.getpeername = (int (PASCAL_FAR *)(SOCKET sock,
+    winSock.getpeername = (int (PASCAL FAR *)(SOCKET sock,
             struct sockaddr FAR *name, int FAR *namelen))
         GetProcAddress(winSock.hInstance, "getpeername");
-    winSock.getservbyname = (struct servent FAR * (PASCAL_FAR *)
+    winSock.getservbyname = (struct servent FAR * (PASCAL FAR *)
             (const char FAR * name, const char FAR * proto))
         GetProcAddress(winSock.hInstance, "getservbyname");
-    winSock.getsockname = (int (PASCAL_FAR *)(SOCKET sock,
+    winSock.getsockname = (int (PASCAL FAR *)(SOCKET sock,
             struct sockaddr FAR *name, int FAR *namelen))
         GetProcAddress(winSock.hInstance, "getsockname");
-    winSock.WSAStartup = (int (PASCAL_FAR *)(WORD wVersionRequired,
+    winSock.WSAStartup = (int (PASCAL FAR *)(WORD wVersionRequired,
             LPWSADATA lpWSAData)) GetProcAddress(winSock.hInstance, "WSAStartup");
-    winSock.WSACleanup = (int (PASCAL_FAR *)(void))
+    winSock.WSACleanup = (int (PASCAL FAR *)(void))
         GetProcAddress(winSock.hInstance, "WSACleanup");
-    winSock.WSAGetLastError = (int (PASCAL_FAR *)(void))
+    winSock.WSAGetLastError = (int (PASCAL FAR *)(void))
         GetProcAddress(winSock.hInstance, "WSAGetLastError");
-    winSock.WSAAsyncSelect = (int (PASCAL_FAR *)(SOCKET s, HWND hWnd,
+    winSock.WSAAsyncSelect = (int (PASCAL FAR *)(SOCKET s, HWND hWnd,
             u_int wMsg, long lEvent))
         GetProcAddress(winSock.hInstance, "WSAAsyncSelect");
 
